@@ -1,28 +1,17 @@
 /*
- * Copyright (C) 2020 Mikhail Zolotukhin <zomial@protonmail.com>
+ * SPDX-FileCopyrightText: 2020 Mikhail Zolotukhin <zomial@protonmail.com>
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
+#include <QDir>
 #include <QString>
 #include <QVariant>
+#include <QRegularExpression>
 
 #include "configeditor.h"
 
+QString gtk2Theme();
 void upgradeGtk2Theme();
 void upgradeGtk3Theme();
 
@@ -33,7 +22,7 @@ int main() {
 }
 
 void upgradeGtk2Theme() {
-    QString currentGtk2Theme = ConfigEditor::gtk2ConfigValue(QStringLiteral("gtk-theme-name"));
+    QString currentGtk2Theme = gtk2Theme();
     if (currentGtk2Theme.isEmpty()
      || currentGtk2Theme == QStringLiteral("oxygen-gtk")
      || currentGtk2Theme == QStringLiteral("BreezyGTK")
@@ -55,3 +44,20 @@ void upgradeGtk3Theme() {
         ConfigEditor::setGtk3ConfigValueXSettingsd(QStringLiteral("Net/ThemeName"), QStringLiteral("Breeze"));
     }
 }
+
+QString gtk2Theme()
+{
+    QString gtkrcPath = QDir::homePath() + QStringLiteral("/.gtkrc-2.0");
+    QFile gtkrc(gtkrcPath);
+    if (gtkrc.open(QIODevice::ReadWrite | QIODevice::Text)) {
+        const QRegularExpression regExp(QStringLiteral("gtk-theme-name=[^\n]*($|\n)"));
+        while (!gtkrc.atEnd()) {
+            QString line = gtkrc.readLine();
+            if (line.contains(regExp)) {
+                return line.split('"')[1];
+            }
+        }
+    }
+
+    return QString();
+}
